# Z490 Vision G OpenCore Readme

Follow the Instructions on my [**Github Repo**](https://github.com/5T33Z0/Gigabyte-Z490-Vision-G-Hackintosh-OpenCore) to use this EFI Folder and its `config.plist` correctly. 

## Disabled SSDTs and Kexts
The following SSDTs and Kexts are disabled by default since I don't know which SMBIOS, CPU, GPU and hard disk type you will be using.

- **Disabled SSDTs**
	- [**SSDT-I225**](https://github.com/5T33Z0/OC-Little-Translated/tree/main/01_Adding_missing_Devices_and_enabling_Features/Intel_I225-V_Fix_(SSDT-I225V)) &rarr; Fixes Intel I225V Internet Controller using stock firmware. If you have flashed a custom firmware you don't need this.
	- [**SSDT-RX580**](https://github.com/5T33Z0/OC-Little-Translated/tree/main/01_Adding_missing_Devices_and_enabling_Features/AMD_Radeon_Tweaks) &rarr; Only for Radeon RX580 Cards. Improves Metal Performance. See the [test resuls](https://github.com/5T33Z0/Gigabyte-Z490-Vision-G-Hackintosh-OpenCore/tree/main/OC_Benchmarks#gpu-computing-benchmarks)
	- [**SSDT-DMAC**](https://github.com/5T33Z0/OC-Little-Translated/tree/main/01_Adding_missing_Devices_and_enabling_Features/DMA_Controller_(SSDT-DMAC)#readme) &rarr; Cosmetic
	- [**SSDT-FWHD**](https://github.com/5T33Z0/OC-Little-Translated/tree/main/01_Adding_missing_Devices_and_enabling_Features/Fake_Firmware_Hub_(SSDT-FWHD)#readme) &rarr; Cosmetic
	- [**SSDT-PMC**](https://github.com/5T33Z0/OC-Little-Translated/tree/main/01_Adding_missing_Devices_and_enabling_Features/PMC_Support_(SSDT-PMC)#readme) &rarr; Cosmetic
- **Disabled Kexts**
	- `AGPMInjector.kext` – Injects Apple Grpahics Power Management into the GPU. Deisabled by default since I don't know which GPU you are using. Generate your own kext with [AGPMInjector](https://github.com/Pavo-IM/AGPMInjector) 
	- `CPUFriend.kext` 
	- `CPUFriendDataProvider.kext` – must be generated individually as well using [CPUFriendFriend](https://github.com/corpnewt/CPUFriendFriend). Follow the "Post-Install Tweaks" Section of the repo on how to do this.
	- `FeatureUnlock.kext` - Unlocks Content Caching under "Sharing"
	- `RestrictEvents.kext` - Enable when using SMBIOS `MacPro7,1`. Removes warning about unpopulated RAM Slots. Requires additional boot-arg: `revpatch=auto`
	- [`NVMeFix.kext`](https://github.com/acidanthera/NVMeFix#readme) – since I don't know if you are using a NVMe-SSD or not.

## Enabling the Intel I225-V Ethernet Controller

|macOS |Procedure|
|-------------|---------|
**12 and 13 beta**| **Prerequisites**: [Fix the Controller](https://github.com/5T33Z0/Gigabyte-Z490-Vision-G-Hackintosh-OpenCore/blob/main/I225-V_FIX.md). Once that's done, change the following settings:</br></br> 1. **ACPI/Add** &rarr; Disable `DMAR.aml` </br>2. **ACPI/Delete** &rarr; Disable `Drop OEM DMAR Table`<br>3. **DeviceProperties** &rarr; Disable `PciRoot(0x0)/Pci(0x1C,0x1)/Pci(0x0,0x0)` (put a hash symbol `#` in front of it)<br> 4. **Kernel/Quirks** &rarr; Uncheck `DisableIOMapper`</br>5. **Boot-args** &rarr; Disable/Delete `dk.e1000=0` and/or `e1000=0` (put `#` in front of them)</br></br>**NOTE**: This is the default configuration. If you are using my config, you don't have to change anything here!
**11.4+**|1. Disable `PciRoot(0x0)/Pci(0x1C,0x1)/Pci(0x0,0x0)` (put `#` in front of it)</br> 2. Add boot-arg `dk.e1000=0`</br> 3. Save and reboot
**10.15 to 11.3**|1. Enable `#PciRoot(0x0)/Pci(0x1C,0x1)/Pci(0x0,0x0)` (delete `#`)</br> 2. Go to `Kernel/Patch` and enable `I225-V Patch`.</br> 3. Delete/disable boot-arg `dk.e1000=0`</br> 4. Save and reboot.
**10.14 and older**| Not compatible. You need a third party Ethernet Card.

### Settings combinations, custom firmware:

macOS         |Vt-D    |DisableIoMapper |DMAR (OEM) |DMAR (dropped/replaced) |I225-V / 3rd Party working|
:-------------|:------:|:--------------:|:---------:|:----------------------:|:--------------------------:
11.4 to 13.0  | **ON** |**OFF**         | **YES**   | **NO / NO**            | **YES / YES**
11.4 to 12.5  | ON     | OFF            | NO        | YES / YES              | YES/ NO
11.4 to 12.5  | OFF/ON |ON              | NO        | YES / YES              | NO / YES
10.15 to 11.3 | OFF/ON |ON              | YES       | NO / NO                | **YES / YES**

### Settings combinations, stock firmware

macOS             |Vt-D|DisableIoMapper|DMAR (OEM)|DMAR (dropped/replaced)| I225-V / 3rd Party working|
:-----------------|----|:-------------:|:--------:|:---------------------:|:-----------------:
12.5+ (Fix [Opt. 1](https://github.com/5T33Z0/Gigabyte-Z490-Vision-G-Hackintosh-OpenCore/blob/main/I225-V_FIX.md#option-1-using-a-ssdt-with-corrected-header-description))| ON |**OFF**   | **YES**  | **NO / NO**           | **YES / YES**
12.5+ (stock fw)  | ON |**OFF**        | **YES**  | **NO / NO**           | **NO / YES**
11.4 to 11.6.7    | ON | ON [^1]       | NO       | YES / YES             | [**YES / YES**](https://github.com/5T33Z0/Gigabyte-Z490-Vision-G-Hackintosh-OpenCore/issues/19#issuecomment-1153315826)
10.15 to 11.3     | OFF/ON|OFF/ON      | YES      | NO / NO               | **YES / NO**

If you can't access the Internet after applying the settings, remove the following files via Terminal and reboot:

- `sudo rm /Library/Preferences/SystemConfiguration/NetworkInterfaces.plist`
- `sudo rm /Library/Preferences/SystemConfiguration/preferences.plist` 

[^1]: Combining `Vt-D` and `DisableIOMapper` makes no sense to me in regards to getting the I225-V working in macOS but that's what the user reported as working.
## Running a legacy version of macOS

### Avoid macOS High Sierra
I know being able to run macOS High Sierra might be tempting for those using an NVIDIA Kepler Card since it's the last version that supports NVIDIA WebDrivers, but I strongly advise against it if you want to run macOS Big Sur or newer. If you just need 32 bit support, I'd recommend to install macOS Mojave instead.

**Avoid macOS High Sierra** because it changes something in the System Definition of Big Sur's  PreBoot Volume that it won't boot afterwards – even if you install it on a different disk! After you've shut down High Sierra and boot back into Big Sur, you will be greeted with the dreaded crossed-out circle of death instead. In this case, you need to use the `-no_compat_check` boot-arg to be able to start mac Big Sur again. 

Next, you have to either perform some terminal wizardry to fix the issue (which I couldn't find again when writing this) or re-install Big Sur over your existing Install to fix it. You could say, "well, I just leave the `-no_compat_check` argument enabled then and carry on." Of course, you could do that, but keep in mind that you won't be able to install any system updates via Software Update in this case.

#### About `config_iMac19,1.plist` 

This config is for installing and running your Hackintosh as an `iMac19,1` so you are able to install and run legacy OSes such as macOS Mojave. The main difference to the primary config.plist are as follows:

- Uses SMBIOS for iMac19,1
- Emulates an i9-9900K Processor since Mojave doesn't support 10th Gen Intel CPUs (see Kernel/Emulate section)
- Uses a different Framebuffer Patch and device-id, otherwise the boot is stalling 
- Internet is not working the I225-V is not supported before macOS Big Sur officially. You either need a 3rd Party Ethernet Card or use USB tethering via a mobile phone. If you have an iPhone I think it works out the box. Android users can use [**HoRNDIS Kext**](https://github.com/jwise/HoRNDIS) to enable USB Tethering.

**NOTE**: Although I created this config to be able to run a 32 bit supported version of macOS, it actually can boot everything from Mojave up to Monterey. I did some benchmarking test comparing result from iMac19,1 and iMac20,2 where iMac19,1 actually came out on top.